@@ -432,6 +432,18 @@ def hrs_merge_weekly_rehiring_data(username, password, server_name, share_name,
         print('No rehiring data found for the specified dates.')
 
 
+def normalize_value(val):
+    """ Normalize value by converting NaN to empty string and stripping whitespace.
+
+    Args:
+        val(any): The value to normalize.
+
+    Returns:
+
+    """
+    return '' if pd.isna(val) else str(val).strip()
+
+
 def hrs_compare_excel_data(username, password, server_name, share_name, from_data, from_key_column, update_data, update_key_column, config_folder_path, config_file_name,
                            config_sheet_name, port=445):
     """ This function compares rehiring data from the last two weeks and returns the differences.
@@ -525,8 +537,8 @@ def hrs_compare_excel_data(username, password, server_name, share_name, from_dat
                         from_column_name = from_data_columns_dict[from_pd_column_index]
                         update_column_name = update_data_columns_dict[update_pd_column_index]
 
-                        from_value = from_row_dict.get(from_column_name, '')
-                        update_value = update_row_dict.get(update_column_name, '')
+                        from_value = normalize_value(from_row_dict.get(from_column_name, ''))
+                        update_value = normalize_value(update_row_dict.get(update_column_name, ''))
 
                         if from_value != update_value:
                             check_result = OrderedDict()
