@@ -160,6 +160,9 @@ class MiniRpaManager(MiniRpaFunction):
                     sap_automation.input_field_single_value(sap_operation_dict['field_title'], int(sap_operation_dict['field_index']), sap_operation_dict['field_value'],
                                                             is_enter,
                                                             is_tab, need_click_tip)
+                elif function_name == 'input_field_single_value_with_field_label':
+                    sap_automation.input_field_single_value_with_field_label(sap_operation_dict['field_label'], int(sap_operation_dict['field_index']),
+                                                                             sap_operation_dict['field_value'], is_enter, is_tab, need_click_tip)
                 elif function_name == 'click_execute_button':
                     sap_automation.click_execute_button()
                 elif function_name == 'click_output_button':
@@ -188,7 +191,7 @@ class MiniRpaManager(MiniRpaFunction):
                 elif function_name == 'download_excel_by_menu_click':
                     sap_automation.download_excel_by_menu_click(sap_operation_dict['file_name'])
                 elif function_name == 'download_excel_by_views_button_click':
-                    sap_automation.download_excel_by_views_button_click(sap_operation_dict['file_name'])
+                    sap_automation.download_excel_by_views_button_click(sap_operation_dict['file_name'], sap_operation_dict['spreadsheet_title'])
                 elif function_name == 'download_excel_by_export_button_click':
                     sap_automation.download_excel_by_export_button_click(sap_operation_dict['file_name'])
                 elif function_name == 'select_layout_before_download_excel':
