@@ -9,7 +9,7 @@ SE16_TABLE_NAME_INPUT_CSS_SELECTOR = "input[title='Table Name']"
 POPUP_WINDOW_OK_BUTTON_CSS_SELECTOR = ".urPWInnerBorder div[title='Continue (Enter)']"
 REPORTING_PERIOD_CSS_SELECTOR = "div[title^='Reporting Period:']"
 # REPORTING_PERIOD_DROPDOWN_CSS_SELECTOR = "input[aria-roledescription='Dropdown List Box']"
-REPORTING_PERIOD_DROPDOWN_CSS_SELECTOR = "input[value='Key Date']"
+REPORTING_PERIOD_DROPDOWN_CSS_SELECTOR = "input[placeholder='*']"
 REPORTING_PERIOD_DROPDOWN_LIST_CSS_SELECTOR = "#DD_DATESAPLHR_QUERY_APPL_AREA-scrl div.lsListbox__values"
 QUERY_PARAMETER_TR_CSS_SELECTOR = "table[id$='mrss-cont-none-content'] tr[id*='mrss-cont-none-Row'][id^='C']"
 OUTPUT_BUTTON_CSS_SELECTOR = "div[title='Start output (F8)']"
@@ -20,8 +20,10 @@ LOG_OFF_CSS_SELECTOR = 'div[title="Log Off (Shift+F3)"]'
 SAP_QUERY_INPUT_NAME = "SAP Query (S): Query name"
 SAP_INFO_SET_INPUT_CSS_SELECTOR = "input[title='SAP Query (S): InfoSet']"
 SAP_INFO_SET_SPAN_CSS_SELECTOR = "span[title='SAP Query (S): InfoSet']"
-SAP_INFO_SET_ROWS_TR_CSS_SELECTOR = "tr[id^='SHresultgrid'][id*='mrss-cont-none-Row']"
-SAP_INFO_SET_ROWS_SPAN_CSS_SELECTOR = "tr[id^='SHresultgrid'][id*='mrss-cont-none-Row'] td:first-child div span"
+# SAP_INFO_SET_ROWS_TR_CSS_SELECTOR = "tr[id^='SHresultgrid'][id*='mrss-cont-none-Row']"
+SAP_INFO_SET_ROWS_TR_CSS_SELECTOR = "table[id^='SHresultgrid'][id*='mrss-cont-none-content'] tr"
+# SAP_INFO_SET_ROWS_SPAN_CSS_SELECTOR = "tr[id^='SHresultgrid'][id*='mrss-cont-none-Row'] td:first-child div span"
+SAP_INFO_SET_ROWS_SPAN_CSS_SELECTOR = "table[id^='SHresultgrid'][id*='mrss-cont-none-content'] tr td:first-child div span"
 SAP_INFO_SET_COPY_BUTTON_NAME = "Copy"
 FAILED_LOAD_MESSAGE_CSS_SELECTOR = "span.lsMessageBar__text"
 INITIALIZE_BUTTON_CSS_SELECTOR = "div[title='Initialize Values (Shift+F1)']"
@@ -179,6 +181,51 @@ class MiniRpaSapAutomation:
         else:
             raise ValueError(f'Cannot find field: {field_title} with index: {field_index}')
 
+    def input_field_single_value_with_field_label(self, field_label, field_index, field_value, is_enter, is_tab, need_click_tip):
+        """ This function is used to input single field value in SE16.
+
+        Args:
+            field_index(int): This is the index of field. e.g. 1,2
+            is_enter(bool): This is the flag whether to press enter
+            is_tab(bool): This is the flag whether to press tab
+            need_click_tip(bool): This is the flag whether to click tip
+            field_label(str): This is the label of field
+            field_value(str): This is the value of field
+        """
+        field_label = str(field_label).strip()
+        sleep(2)
+        self.web_rpa.wait_element_presence_by_css_selector("div.lsRLItemCnt")
+        all_filed_elements = self.web_rpa.browser.find_elements(By.CSS_SELECTOR, "div.lsRLItemCnt")
+
+        start_to_search = False
+        current_input_index = 0
+        for field_element in all_filed_elements:
+            try:
+                label_element = field_element.find_element(By.CSS_SELECTOR, "span label span")
+                label_text = label_element.text.strip()
+                if label_text == field_label:
+                    start_to_search = True
+                    current_input_index = 0
+                    continue
+                else:
+                    pass
+            except NoSuchElementException:
+                if start_to_search:
+                    try:
+                        input_element = field_element.find_element(By.CSS_SELECTOR, "table tbody tr td:first-child input")
+                        current_input_index += 1
+                        if current_input_index == field_index:
+                            self.web_rpa.move_to_and_click_element('', target_element=input_element)
+                            sleep(1)
+                            self.web_rpa.fill_input_field_with_single_value(field_value, '', is_enter, is_tab, need_click_tip, '', input_element)
+                            sleep(1)
+                            return
+                    except NoSuchElementException:
+                        continue
+
+        if not start_to_search:
+            raise ValueError(f'Cannot find field label: {field_label}')
+
     def input_field_multiple_values(self, field_button_index, tab_index, field_values, second_field_values):
         """ This function is used to input multiple field values in SE16.
 
@@ -396,7 +443,8 @@ class MiniRpaSapAutomation:
 
         self.web_rpa.activate_context_click(column_css_selector)
         sleep(2)
-        self.web_rpa.click_or_input_by_css_selector(f"tr[aria-label^='{context_menu_item_name}']", 'click')
+        self.web_rpa.click_or_input_by_css_selector(f"//tr/td/span[contains(., '{context_menu_item_name}')]", 'click', by=By.XPATH)
+        # self.web_rpa.click_or_input_by_css_selector(f"tr[aria-label^='{context_menu_item_name}']", 'click')
         # self.web_rpa.move_to_and_click_element(f"tr[aria-label^='{context_menu_item_name}']")
         sleep(1)
 
@@ -443,12 +491,15 @@ class MiniRpaSapAutomation:
             sleep(1)
             self.web_rpa.input_download_excel_file_name(file_name, True, self.user_name, self.user_password, self.server_name, self.share_name, self.report_save_path)
 
-    def download_excel_by_views_button_click(self, file_name):
+    def download_excel_by_views_button_click(self, file_name, spreadsheet_title=None):
         """ This function is used to download Excel by views button click.
 
         Args:
             file_name(str): This is the name of file
+            spreadsheet_title(str): This is the name of spreadsheet button
         """
+        if not spreadsheet_title:
+            spreadsheet_title = 'Spreadsheet... (Ctrl+Shift+F7)'
         sleep(2)
         self.web_rpa.wait_invisibility_of_loading_window()
         sleep(1)
@@ -459,16 +510,17 @@ class MiniRpaSapAutomation:
         self.web_rpa.wait_invisibility_of_loading_window()
         self.web_rpa.wait_element_invisible_by_css_selector("div[title='Views']")
         sleep(1)
-        self.web_rpa.activate_context_click('#cuaheader-title')
-        self.web_rpa.click_or_input_by_css_selector("tr[aria-label^='Spreadsheet...']", 'click')
-        sleep(1)
-        is_cancelled = self.web_rpa.input_download_excel_file_name(file_name, True, self.user_name, self.user_password, self.server_name, self.share_name, self.report_save_path)
-        if is_cancelled:
-            self.web_rpa.wait_invisibility_of_loading_window()
-            self.web_rpa.activate_context_click('#cuaheader-title')
-            self.web_rpa.click_or_input_by_css_selector("tr[aria-label^='Spreadsheet...']", 'click')
-            sleep(1)
-            self.web_rpa.input_download_excel_file_name(file_name, True, self.user_name, self.user_password, self.server_name, self.share_name, self.report_save_path)
+        self.download_excel_by_click_spreadsheet_button(spreadsheet_title, file_name)
+        # self.web_rpa.activate_context_click('#cuaheader-title')
+        # self.web_rpa.click_or_input_by_css_selector("tr[aria-label^='Spreadsheet...']", 'click')
+        # sleep(1)
+        # is_cancelled = self.web_rpa.input_download_excel_file_name(file_name, True, self.user_name, self.user_password, self.server_name, self.share_name, self.report_save_path)
+        # if is_cancelled:
+        #     self.web_rpa.wait_invisibility_of_loading_window()
+        #     self.web_rpa.activate_context_click('#cuaheader-title')
+        #     self.web_rpa.click_or_input_by_css_selector("tr[aria-label^='Spreadsheet...']", 'click')
+        #     sleep(1)
+        #     self.web_rpa.input_download_excel_file_name(file_name, True, self.user_name, self.user_password, self.server_name, self.share_name, self.report_save_path)
 
     def download_excel_by_export_button_click(self, file_name):
         """ This function is used to download Excel by export click.
